pub enum CoinbaseSpendRestriction {
DisallowCoinbaseSpend,
CheckCoinbaseMaturity {
spend_height: Height,
},
}Expand description
A restriction that must be checked before spending a transparent output of a coinbase transaction.
See the function transparent_coinbase_spend in zebra-state for the
consensus rules.
Variants
DisallowCoinbaseSpend
The UTXO is spent in a transaction with one or more transparent outputs on a network where coinbase outputs must not be spent by transactions with transparent outputs.
CheckCoinbaseMaturity
The UTXO is spent in a transaction which only has shielded outputs, or transactions spending coinbase outputs may have transparent outputs on this network.