pub struct OrderedUtxo {
pub utxo: Utxo,
pub tx_index_in_block: usize,
}Expand description
A Utxo, and the index of its transaction within its block.
This extra index is used to check that spends come after outputs, when a new output and its spend are both in the same block.
The extra index is only used during block verification, so it does not need to be sent to the state.
Fields
utxo: UtxoAn unspent transaction output.
tx_index_in_block: usizeThe index of the transaction that created the output, in the block at height.
Used to make sure that transaction can only spend outputs that were created earlier in the chain.
Note: this is different from OutPoint.index,
which is the index of the output in its transaction.
Implementations
Sourceimpl OrderedUtxo
impl OrderedUtxo